/*
 * Copyright (c) 2015, 2017 Cisco Systems, Inc. and others.  All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v1.0 which accompanies this distribution,
 * and is available at http://www.eclipse.org/legal/epl-v10.html
 */

package org.opendaylight.controller.config.facade.xml.mapping.attributes.toxml;

import com.google.common.base.Optional;
import com.google.common.base.Preconditions;
import java.util.Map;
import org.opendaylight.controller.config.facade.xml.util.Util;
import org.opendaylight.controller.config.util.xml.XmlUtil;
import org.opendaylight.yangtools.yang.common.QName;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

public class SimpleIdentityRefAttributeWritingStrategy extends SimpleAttributeWritingStrategy {

    private static final String PREFIX = "prefix";

    public SimpleIdentityRefAttributeWritingStrategy(final Document document, final String key) {
        super(document, key);
    }

    @Override
    protected Object preprocess(final Object value) {
        Util.checkType(value, Map.class);
        Preconditions.checkArgument(((Map<?, ?>) value).size() == 1, "Unexpected number of values in %s, expected 1",
                value);
        Object stringValue = ((Map<?, ?>) value).values().iterator().next();
        Util.checkType(stringValue, String.class);

        return stringValue;
    }

    @Override
    protected Element createElement(final Document doc, final String key, final String value,
            final Optional<String> namespace) {
        QName qualifiedName = QName.create(value);
        String identityValue = qualifiedName.getLocalName();
        String identityNamespace = qualifiedName.getNamespace().toString();
        return XmlUtil.createTextElementWithNamespacedContent(doc, key, PREFIX, identityNamespace, identityValue,
                namespace);
    }
}
